==> silk-0.9.0.jar: META-INF/leiningen/org.silkyweb/silk/README.md <==
# SILK WEB TOOLKIT

## About

A compile time web publishing toolkit created at [bheap ltd](http://www.bheap.co.uk/) and improved by the [community](http://www.silkyweb.org/community.html).

Silk allows you to build static websites out of re-usable building blocks without the use of server side languages, just use HTML, CSS and Javascript.  Sites built with Silk are clean from semantic pollution, no tag soup.

Improve the security of the web, use static wherever possible.  How many sites are dynamic beyond a contact form really ?  Why generate site content for every visit when you can do it once ?


## Getting Started

### Installation

There are binaries for a number of platforms on the releases page.

Alternatively you can run the custom installation script which will put silk in ~/bin.

    bash <(curl -fksSL https://raw.githubusercontent.com/silk-web-toolkit/silk/develop/install/install.sh)

### Development

Run lein uberjar to build a single jar file for the project.

### Releases and distribution

See the build instructions in build/README.md to build for various platforms.


## Status

Silk is already used in commercial projects at large multinationals.


## Documentation

[Documentation](http://www.silkyweb.org/documentation.html).

Please see the [silkyweb.org site](http://www.silkyweb.org/) for more documentation.


## Community

[The team](http://www.silkyweb.org/community.html).

Join in over on our <a href="http://groups.google.com/group/silk-user">mailing list</a>.


## License

Silk is licensed with Apache License v2.0.

==> silk-0.11.0.jar: META-INF/leiningen/org.silkyweb/silk/README.md <==
# SILK WEB TOOLKIT

[![Clojars Project](https://img.shields.io/clojars/v/org.silkyweb/silk.svg)](https://clojars.org/org.silkyweb/silk)

## About

A compile time web publishing toolkit created at [bheap ltd](http://www.bheap.co.uk/) and improved by the [community](http://www.silkyweb.org/community.html).

Silk allows you to build static websites out of re-usable building blocks without the use of server side languages, just use HTML, CSS and Javascript.  Sites built with Silk are clean from semantic pollution, no tag soup.

Improve the security of the web, use static wherever possible.  How many sites are dynamic beyond a contact form really ?  Why generate site content for every visit when you can do it once ?


## Getting Started

### Installation

There are binaries for a number of platforms on the releases page.

Alternatively you can run the custom installation script which will put silk in ~/bin.

    bash <(curl -fksSL https://raw.githubusercontent.com/silk-web-toolkit/silk/develop/install/install.sh)

### Development

Run lein uberjar to build a single jar file for the project.

### Releases and distribution

See the build instructions in build/README.md to build for various platforms.


## Status

Silk is already used in commercial projects at large multinationals.


## Documentation

[Documentation](http://www.silkyweb.org/documentation.html).

Please see the [silkyweb.org site](http://www.silkyweb.org/) for more documentation.


## Community

[The team](http://www.silkyweb.org/community.html).

Join in over on our <a href="http://groups.google.com/group/silk-user">mailing list</a>.


## License

Silk is licensed with Apache License v2.0.
